pub enum Priority {
High,
Normal,
Background,
}Expand description
Scheduling priority for tasks in the general worker pool.
Variants
High
Latency-sensitive work.
Normal
Ordinary work.
Background
Work that may make progress at a lower rate.