[−][src]Function async_runtime::rt::current_rt
pub fn current_rt() -> Option<RtConfig>
Get the configuration for the current default executor.
Note that if this returns None and you call spawn, a default executor
will be initialized, after which this will no longer return None.
If you are a library author you can use this to generate a clean error message if you have a hard requirement for a certain executor.