RunStats

Struct RunStats 

#[non_exhaustive]
pub struct RunStats { pub drive_steps: usize, pub elapsed: Duration, pub inbox_commands: usize, }
Statistics from a time-budgeted LocalDomain drive.

A drive step has the same scheduling semantics as LocalDomain::try_tick: it may materialize one remote inbox command and gives an already-materialized local runnable one opportunity to make progress. It is not a count of completed tasks or individual Future::poll calls.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
drive_steps: usize

Number of non-blocking drive steps that made progress.

elapsed: Duration

Wall-clock time spent in this drive call.

inbox_commands: usize

Number of remote inbox commands materialized by these drive steps.